@@ -34,6 +34,9 @@ COMMON_REPLACEMENTS = {"pct": "precinct",
                        "8th": "8",
                        "9th": "9",
                        "10th": "10",
+                       "11th": "11",
+                       "12th": "12",
+                       "13th": "13",
                        "one": "1",
                        "two": "2",
                        "three": "3",
@@ -58,13 +61,13 @@ COMMON_REPLACEMENTS = {"pct": "precinct",
                        "pk": "park",
                        "mt": "mountain",
                        "mount": "mountain",
-                       "ind": "independent"
+                       "ind": "independent",
+                       "sq": "square",
                        }
 
 ACCEPTABLE_DIFFERENCES = set(["district", "ward", "precinct", "borough", "number"])
 # TODO: Check with ppl about "twp" and if it is ok to map ward to precinct
-AGGRESSIVE_REPLACEMENTS = {"wd": "precinct",
-                           "ward": "precinct"
+AGGRESSIVE_REPLACEMENTS = {"m": "middle" # kinda aggressive
                            } # never used
 
 class PrecinctMatcher:
